WebLiteRtService class
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
loadLiteRt(
{String? wasmPath}) → Future< void> -
Loads the LiteRT core WebAssembly runtime binaries.
override
-
loadLiteRtLm(
{String? moduleUrl}) → Future< void> -
Loads the LiteRT-LM runtime for LLMs.
override
-
loadLmModel(
String modelPath, {String accelerator = 'gpu'}) → Future< LiteRtLmModel> -
Loads and compiles a
.litertlmlanguage model.override -
loadModel(
String modelPath, {String accelerator = 'webgpu'}) → Future< LiteRtModel> -
Loads and compiles a general
.tflitemodel.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited