LiteRtLmModel class abstract

Interface representing a loaded and compiled LiteRT-LM language model.

Implementers

Constructors

LiteRtLmModel()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
Releases the resources allocated for this model.
generateStream(String prompt, {int maxTokens = 512, double temp = 0.4, double topP = 0.9, int topK = 40, int? seed}) Stream<String>
Generates a streaming response for the given prompt.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited