LiteRtModel class abstract
Interface representing a loaded and compiled general LiteRT (.tflite) model.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< void> - Releases the resources allocated for this model.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
Float32List input, List< int> shape) → Future<Float32List> - Runs inference on the model with the given input tensor. Returns the output tensor as a Float32List.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited