run abstract method
Runs inference on the model with the given input tensor. Returns the output tensor as a Float32List.
Implementation
Future<Float32List> run(Float32List input, List<int> shape);
Runs inference on the model with the given input tensor. Returns the output tensor as a Float32List.
Future<Float32List> run(Float32List input, List<int> shape);