LiteRtModelInfo class

Metadata information for a LiteRT model available for edge execution.

Constructors

LiteRtModelInfo({required String id, required String name, required String description, required LiteRtModelType type, required String downloadUrl, required int sizeBytes})
const

Properties

description String
final
displaySize String
Human-readable file size (e.g. "1.5 GB", "30 MB").
no setter
downloadUrl String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeBytes int
final
type LiteRtModelType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited